# CHANGELOG


## v0.0.13 (September 15, 2020)


- Use full timestamps for database dumps.


---


## v0.0.12 (September 15, 2020)

- Added `db dump` and `db load` export import commands for PostgreSQL.


---


## v0.0.11 (September 02, 2020)

- `tea-console` update.


---


## v0.0.10 (September 01, 2020)

- Add `running_duration` to `TimerMixin`.


--


## v0.0.9 (September 01, 2020)

- Added views for JWT token generation and refresh.
- Switch to simplejwt.


---


## v0.0.8 (August 28, 2020)

- Added creation of main entry point for django application.


---


## v0.0.7 (August 24, 2020)

- Fixing requirements.


---


## v0.0.6 (August 24, 2020)

- Add colored serializers.
- Add rest framework exception handler.


---


## v0.0.5 (August 24, 2020)

- Fix secret key saving into config file.
- Rename project to `tea-django`.


---


## v0.0.4 (August 23, 2020)

- Fixes.


---


## v0.0.3 (August 23, 2020)
- Move stuff to `tea-console` and `tea` projects. 


---


## v0.0.1 (August 17, 2020)

- Initial beta release. 
